==> odoo_addon_partner_contact_address_default-15.0.1.0.0.6-py3-none-any.whl: odoo/addons/partner_contact_address_default/tests/test_partner_contact_address_default.py <==
# Copyright 2020 Tecnativa - Carlos Dauden
# Copyright 2020 Tecnativa - Sergio Teruel
# License AGPL-3.0 or later (https://www.gnu.org/licenses/agpl.html).
from odoo.tests import common


class TestPartnerContactAddressDefault(common.TransactionCase):
    def setUp(self):
        super().setUp()
        self.Partner = self.env["res.partner"]
        self.partner = self.Partner.create({"name": "Parent partner"})
        self.partner_child_delivery1 = self.Partner.create(
            {
                "name": "Child delivery 1",
                "type": "delivery",
                "parent_id": self.partner.id,
            }
        )
        self.partner_child_delivery2 = self.Partner.create(
            {
                "name": "Child delivery 2",
                "type": "delivery",
                "parent_id": self.partner.id,
            }
        )
        self.partner_child_invoice = self.Partner.create(
            {"name": "Child invoice", "type": "invoice", "parent_id": self.partner.id}
        )

    def test_contact_address_default(self):
        self.partner.partner_delivery_id = self.partner
        self.partner.partner_invoice_id = self.partner
        res = self.partner.address_get(["delivery", "invoice"])
        self.assertEqual(res["delivery"], self.partner.id)
        self.assertEqual(res["invoice"], self.partner.id)

        self.partner_child_delivery2.partner_delivery_id = self.partner_child_delivery2
        self.partner_child_delivery2.partner_invoice_id = self.partner_child_delivery2
        res = self.partner_child_delivery2.address_get(["delivery", "invoice"])
        self.assertEqual(res["delivery"], self.partner_child_delivery2.id)
        self.assertEqual(res["invoice"], self.partner_child_delivery2.id)

    def test_contact_address_archived(self):
        self.partner.partner_delivery_id = self.partner_child_delivery2
        self.partner.partner_invoice_id = self.partner_child_invoice
        self.partner_child_invoice.write({"active": False})
        self.partner_child_delivery2.write({"active": False})
        res = self.partner.address_get(["delivery", "invoice"])
        # As partner_child_delivery2 is archived, even though it is set as
        # partner_delivery_id it should fall back to partner_child_delivery1 here:
        self.assertEqual(res["delivery"], self.partner_child_delivery1.id)
        self.assertEqual(res["invoice"], self.partner.id)

==> odoo_addon_partner_contact_address_default-16.0.1.0.0.2-py3-none-any.whl: odoo/addons/partner_contact_address_default/tests/test_partner_contact_address_default.py <==
# Copyright 2020 Tecnativa - Carlos Dauden
# Copyright 2020 Tecnativa - Sergio Teruel
# License AGPL-3.0 or later (https://www.gnu.org/licenses/agpl.html).
from odoo.tests import common


class TestPartnerContactAddressDefault(common.TransactionCase):
    @classmethod
    def setUpClass(cls):
        super().setUpClass()
        cls.Partner = cls.env["res.partner"]
        cls.partner = cls.Partner.create({"name": "Parent partner"})
        cls.partner_child_delivery1 = cls.Partner.create(
            {
                "name": "Child delivery 1",
                "type": "delivery",
                "parent_id": cls.partner.id,
            }
        )
        cls.partner_child_delivery2 = cls.Partner.create(
            {
                "name": "Child delivery 2",
                "type": "delivery",
                "parent_id": cls.partner.id,
            }
        )
        cls.partner_child_invoice = cls.Partner.create(
            {"name": "Child invoice", "type": "invoice", "parent_id": cls.partner.id}
        )

    def test_contact_address_default(self):
        self.partner.partner_delivery_id = self.partner
        self.partner.partner_invoice_id = self.partner
        res = self.partner.address_get(["delivery", "invoice"])
        self.assertEqual(res["delivery"], self.partner.id)
        self.assertEqual(res["invoice"], self.partner.id)

        self.partner_child_delivery2.partner_delivery_id = self.partner_child_delivery2
        self.partner_child_delivery2.partner_invoice_id = self.partner_child_delivery2
        res = self.partner_child_delivery2.address_get(["delivery", "invoice"])
        self.assertEqual(res["delivery"], self.partner_child_delivery2.id)
        self.assertEqual(res["invoice"], self.partner_child_delivery2.id)

    def test_contact_address_archived(self):
        self.partner.partner_delivery_id = self.partner_child_delivery2
        self.partner.partner_invoice_id = self.partner_child_invoice
        self.partner_child_invoice.write({"active": False})
        self.partner_child_delivery2.write({"active": False})
        res = self.partner.address_get(["delivery", "invoice"])
        # As partner_child_delivery2 is archived, even though it is set as
        # partner_delivery_id it should fall back to partner_child_delivery1 here:
        self.assertEqual(res["delivery"], self.partner_child_delivery1.id)
        self.assertEqual(res["invoice"], self.partner.id)
